Getting started — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Getting started

This guide is here to help you start using PyProcar with the help of our examples and tutorials.

## Installation

The only prerequisite for installing PyProcar is Python itself. If you don’t have Python yet and want the simplest way to get started, we recommend you use the Anaconda Distribution.

Working with conda?

PyProcar is available on conda-forge.

    conda install -c conda-forge pyprocar

Prefer pip?

PyProcar can be installed via pip from PyPI.

    pip install pyprocar

In-depth instructions?

Installing a specific version? Installing from source? Check the Installation page.

Installation

## Paper

1st Publication

Using PyProcar in your research? Please consider citing or acknowledging us. We have a Elsevier Publication!

Authors
2nd Publication

Using PyProcar in your research? Please consider citing or acknowledging us. We have a Elsevier Publication!

Authors

## Support

If you want to support the PyProcar please see the Contributing page.

## Citing PyProcar

There are two papers about PyProcar: 1st Paper and 2nd Paper.

If you are using PyProcar in your scientific research, please help our scientific visibility by citing our work! Head over to Citing PyProcar to learn more about citing PyProcar.